@@ -6,6 +6,9 @@ from sklearn.model_selection import KFold
 import numpy as np
 
 class AWE(ClassifierMixin, BaseEnsemble):
+    """
+    Accuracy Weighted Ensemble
+    """
     def __init__(self, base_estimator=None, n_estimators=10, n_splits=5):
         """Initialization."""
         self.base_estimator = base_estimator
@@ -79,19 +82,20 @@ class AWE(ClassifierMixin, BaseEnsemble):
         """Ensemble support matrix."""
         return np.array([member_clf.predict_proba(X) for member_clf in self.ensemble_])
 
+    def predict_proba(self, X):
+        esm = self.ensemble_support_matrix(X)
+        average_support = np.mean(esm, axis=0)
+        return average_support
+
     def predict(self, X):
         """
         Predict classes for X.
 
-        Parameters
-        ----------
-        X : array-like, shape (n_samples, n_features)
-            The training input samples.
+        :type X: array-like, shape (n_samples, n_features)
+        :param X: The training input samples.
 
-        Returns
-        -------
-        y : array-like, shape (n_samples, )
-            The predicted classes.
+        :rtype: array-like, shape (n_samples, )
+        :returns: The predicted classes.
         """
 
         # Check is fit had been called
