@@ -3,6 +3,7 @@
 import sys
 
 from sklearn.datasets import make_classification
+from sklearn.naive_bayes import GaussianNB
 
 import strlearn as sl
 
@@ -12,18 +13,17 @@ def test_precision_recall():
     chunk_size = 100
     n_chunks = 10
     X, y = make_classification(
-        n_samples=chunk_size * n_chunks, n_features=5,
-        n_classes=2, random_state=1410
+        n_samples=chunk_size * n_chunks, n_features=5, n_classes=2, random_state=1410
     )
 
-    clf = sl.classifiers.AccumulatedSamplesClassifier()
+    clf = sl.classifiers.ASC(base_clf=GaussianNB())
 
     previous_chunk = None
     for chunk_id in range(n_chunks):
         print("Chunk ", chunk_id)
         chunk = (
-            X[chunk_size * chunk_id: chunk_size * chunk_id + chunk_size],
-            y[chunk_size * chunk_id: chunk_size * chunk_id + chunk_size],
+            X[chunk_size * chunk_id : chunk_size * chunk_id + chunk_size],
+            y[chunk_size * chunk_id : chunk_size * chunk_id + chunk_size],
         )
 
         if previous_chunk is not None:
